@@ -41,6 +41,7 @@
 #include "plugin.h"
 #include "filechooser.h"
 #include "mendeleiev.h"
+#include "mesomer.h"
 #include "mesomery.h"
 #include "mesomery-arrow.h"
 #include "reaction.h"
@@ -217,6 +218,7 @@ gcpApplication::gcpApplication ()
 		ReactionStepType = Object::AddType ("reaction-step", CreateReactionStep);
 		Object::AddType ("reactant", CreateReactant, ReactantType);
 		Object::AddType("reaction-arrow", CreateReactionArrow, ReactionArrowType);
+		MesomerType = Object::AddType ("mesomer", NULL);
 		Object::AddType ("mesomery", CreateMesomery, MesomeryType);
 		Object::SetCreationLabel (MesomeryType, _("Create a new mesomery relationship"));
 		Object::AddType("mesomery-arrow", CreateMesomeryArrow, MesomeryArrowType);
@@ -231,7 +233,9 @@ gcpApplication::gcpApplication ()
 		Object::AddRule ("reaction", RuleMustContain, "reaction-arrow");
 		Object::AddRule ("reaction-arrow", RuleMustBeIn, "reaction");
 		Object::AddRule ("reactant", RuleMayContain, "molecule");
-		Object::AddRule ("mesomery", RuleMustContain, "molecule");
+		Object::AddRule ("mesomer", RuleMustContain, "molecule");
+		Object::AddRule ("mesomer", RuleMustBeIn, "mesomery");
+		Object::AddRule ("mesomery", RuleMustContain, "mesomer");
 		Object::AddRule ("mesomery", RuleMustContain, "mesomery-arrow");
 		Object::AddRule ("mesomery-arrow", RuleMustBeIn, "mesomery");
 
@@ -346,6 +350,7 @@ bool gcpApplication::FileProcess(const gchar* filename, int filetype, bool bSave
 	{
 		GtkWidget* message = gtk_message_dialog_new (window, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, 
 															_("Please enter a file name,\nnot a directory"));
+		gtk_window_set_icon_name (GTK_WINDOW (message), "gchempaint");
 		gtk_dialog_run (GTK_DIALOG (message));
 		gtk_widget_destroy (message);
 		return true;
@@ -362,7 +367,6 @@ bool gcpApplication::FileProcess(const gchar* filename, int filetype, bool bSave
 			if (!strcmp(ext, ".gchempaint")) filetype = gcp_ft_Normal;
 			else if (!strcmp(ext, ".cml")) filetype = gcp_ft_CML;
 			else if (!strcmp(ext, ".mol")) filetype = gcp_ft_SDF;
-			else if (!strcmp(ext, ".mdl")) filetype = gcp_ft_SDF;
 			else if (!strcmp(ext, ".sdf")) filetype = gcp_ft_SDF;
 			else if (!strcmp(ext, ".sd")) filetype = gcp_ft_SDF;
 			else if (!strcmp(ext, ".pdb")) filetype = gcp_ft_PDB;
@@ -371,6 +375,7 @@ bool gcpApplication::FileProcess(const gchar* filename, int filetype, bool bSave
 			else {
 				GtkWidget* message = gtk_message_dialog_new (window, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, 
 															_("Sorry, format not supported!"));
+				gtk_window_set_icon_name (GTK_WINDOW (message), "gchempaint");
 				gtk_dialog_run (GTK_DIALOG (message));
 				gtk_widget_destroy (message);
 				return true;
@@ -384,8 +389,7 @@ bool gcpApplication::FileProcess(const gchar* filename, int filetype, bool bSave
 			case gcp_ft_Normal: ext = ".gchempaint"; break;
 			case gcp_ft_CML: ext = ".cml"; break;
 			case gcp_ft_SDF:
-				if (!strcmp(filename + n - 3, "mdl")) ext = ".mdl";
-				else if (!strcmp(filename + n - 3, "sdf")) ext = ".sdf";
+				if (!strcmp(filename + n - 3, "sdf")) ext = ".sdf";
 				else if (!strcmp(filename + n - 2, "sd")) ext = ".sd";
 				else if (bSave) ext = ".mol";
 				break;
@@ -421,6 +425,7 @@ bool gcpApplication::FileProcess(const gchar* filename, int filetype, bool bSave
 		{
 			gchar * message = g_strdup_printf(_("File %s\nexists, overwrite?"), filename2);
 			GtkDialog* Box = GTK_DIALOG(gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, message));
+			gtk_window_set_icon_name (GTK_WINDOW (Box), "gchempaint");
 			result = gtk_dialog_run(Box);
 			gtk_widget_destroy(GTK_WIDGET(Box));
 			g_free(message);
@@ -442,10 +447,9 @@ bool gcpApplication::FileProcess(const gchar* filename, int filetype, bool bSave
 	}
 	else //loading
 	{
-/*		uri = gnome_vfs_uri_new (filename);
+		uri = gnome_vfs_uri_new (filename);
 		err = !gnome_vfs_uri_exists (uri);
-		gnome_vfs_uri_unref (uri);*/
-		err = stat (filename, &buf);
+		gnome_vfs_uri_unref (uri);
 		if (err)
 		{
 			if (!ext)
@@ -453,25 +457,42 @@ bool gcpApplication::FileProcess(const gchar* filename, int filetype, bool bSave
 				{
 					case gcp_ft_SDF:
 						filename2 = g_strdup_printf("%s.%s",filename, "mol");
-						if (!stat(filename2, &buf)) break;
-						g_free(filename2);
-						filename2 = g_strdup_printf("%s.%s",filename, "mdl");
-						if (!stat(filename2, &buf)) break;
+						uri = gnome_vfs_uri_new (filename2);
+						err = !gnome_vfs_uri_exists (uri);
+						gnome_vfs_uri_unref (uri);
+						if (!err)
+							break;
 						g_free(filename2);
 						filename2 = g_strdup_printf("%s.%s",filename, "sdf");
-						if (!stat(filename2, &buf)) break;
+						uri = gnome_vfs_uri_new (filename2);
+						err = !gnome_vfs_uri_exists (uri);
+						gnome_vfs_uri_unref (uri);
+						if (!err)
+							break;
 						g_free(filename2);
 						filename2 = g_strdup_printf("%s.%s",filename, "sd");
-						if (!stat(filename2, &buf)) break;
+						uri = gnome_vfs_uri_new (filename2);
+						err = !gnome_vfs_uri_exists (uri);
+						gnome_vfs_uri_unref (uri);
+						if (!err)
+							break;
 						g_free(filename2);
 						filename2 = g_strdup(filename);
 						break;
 					case gcp_ft_PDB:
 						filename2 = g_strdup_printf("%s.%s",filename, "pdb");
-						if (!stat(filename2, &buf)) break;
+						uri = gnome_vfs_uri_new (filename2);
+						err = !gnome_vfs_uri_exists (uri);
+						gnome_vfs_uri_unref (uri);
+						if (!err)
+							break;
 						g_free(filename2);
 						filename2 = g_strdup_printf("%s.%s",filename, "ent");
-						if (!stat(filename2, &buf)) break;
+						uri = gnome_vfs_uri_new (filename2);
+						err = !gnome_vfs_uri_exists (uri);
+						gnome_vfs_uri_unref (uri);
+						if (!err)
+							break;
 						g_free(filename2);
 						filename2 = g_strdup(filename);
 						break;
@@ -479,10 +500,10 @@ bool gcpApplication::FileProcess(const gchar* filename, int filetype, bool bSave
 						filename2 = g_strdup(filename);
 				}
 			else filename2 = g_strdup_printf("%s%s",filename, ext);
-/*			uri = gnome_vfs_uri_new (filename2);
+			uri = gnome_vfs_uri_new (filename2);
 			err = !gnome_vfs_uri_exists (uri);
-			gnome_vfs_uri_unref (uri);*/
-			if (stat (filename, &buf))
+			gnome_vfs_uri_unref (uri);
+			if (err)
 			{
 				g_free(filename2);
 				filename2 = g_strdup(filename);
@@ -526,7 +547,9 @@ void gcpApplication::OpenWithBabel(const gchar* filename, const gchar* ext, gcpD
 			pDoc = new gcpDocument (this, true);
 		if (local) {
 			ifstream ifs;
-			ifs.open (filename);
+			GnomeVFSURI *uri = gnome_vfs_uri_new (filename);
+			ifs.open (gnome_vfs_uri_get_path (uri));
+			gnome_vfs_uri_unref (uri);
 			if (!ifs) throw (int) 1;
 			old_num_locale = g_strdup (setlocale (LC_NUMERIC, NULL));
 			setlocale(LC_NUMERIC, "C");
@@ -580,6 +603,7 @@ void gcpApplication::OpenWithBabel(const gchar* filename, const gchar* ext, gcpD
 			break;
 		}
 		message = gtk_message_dialog_new(NULL, (GtkDialogFlags) 0, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, mess);
+		gtk_window_set_icon_name (GTK_WINDOW (message), "gchempaint");
 		g_signal_connect_swapped (G_OBJECT (message), "response", G_CALLBACK (gtk_widget_destroy), G_OBJECT (message));
 		gtk_widget_show(message);
 		g_free(mess);
@@ -675,6 +699,7 @@ void gcpApplication::OpenGcp(const gchar* filename, gcpDocument* pDoc)
 			break;
 		}
 		message = gtk_message_dialog_new(NULL, (GtkDialogFlags) 0, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, mess);
+		gtk_window_set_icon_name (GTK_WINDOW (message), "gchempaint");
 		g_signal_connect_swapped (G_OBJECT (message), "response", G_CALLBACK (gtk_widget_destroy), G_OBJECT (message));
 		gtk_widget_show(message);
 		g_free(mess);
@@ -786,6 +811,7 @@ void gcpApplication::OnSaveAsImage ()
 		if (!filename || !strlen(filename) || filename[strlen(filename) - 1] == '/') {
 			GtkWidget* message = gtk_message_dialog_new (GTK_WINDOW (dialog), GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, 
 																_("Please enter a file name,\nnot a directory"));
+			gtk_window_set_icon_name (GTK_WINDOW (message), "gchempaint");
 			gtk_dialog_run (GTK_DIALOG (message));
 			gtk_widget_destroy (message);
 			continue;
@@ -798,6 +824,7 @@ void gcpApplication::OnSaveAsImage ()
 		{
 			gchar * message = g_strdup_printf(_("File %s\nexists, overwrite?"), filename);
 			GtkDialog* Box = GTK_DIALOG(gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, message));
+			gtk_window_set_icon_name (GTK_WINDOW (Box), "gchempaint");
 			result = gtk_dialog_run(Box);
 			gtk_widget_destroy(GTK_WIDGET(Box));
 			g_free(message);
@@ -813,6 +840,7 @@ void gcpApplication::OnSaveAsImage ()
 			else {
 				GtkWidget* message = gtk_message_dialog_new (GTK_WINDOW (dialog), GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, 
 																	"Can't export eps files, please install ps2eps");
+				gtk_window_set_icon_name (GTK_WINDOW (message), "gchempaint");
 				gtk_dialog_run (GTK_DIALOG (message));
 				gtk_widget_destroy (message);
 			}
@@ -823,6 +851,7 @@ void gcpApplication::OnSaveAsImage ()
 		else {
 			GtkWidget* message = gtk_message_dialog_new (GTK_WINDOW (dialog), GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, 
 																_("Sorry, format not supported!"));
+			gtk_window_set_icon_name (GTK_WINDOW (message), "gchempaint");
 			gtk_dialog_run (GTK_DIALOG (message));
 			gtk_widget_destroy (message);
 			continue;
