@@ -83,20 +83,36 @@ gcpDocument::gcpDocument(gcpApplication *App, bool StandAlone): Document()
 	SetActive();
 }
 
-gcpDocument::~gcpDocument()
+gcpDocument::~gcpDocument ()
 {
-	if (m_pCurOp) delete m_pCurOp;
-	if (m_DocPropDlg) m_DocPropDlg->Destroy();
-	if (m_filename) g_free(m_filename);
-	if (m_title) g_free(m_title);
-	if (m_label) g_free(m_label);
-	if (m_author) g_free(m_author);
-	if (m_mail) g_free(m_mail);
-	if (m_comment) g_free(m_comment);
-	map<string, Object*>::iterator it;
-	while (HasChildren()) delete GetFirstChild(it);
-	m_pApp->RemoveDocument(this);
-	if (m_pView) delete m_pView;
+	m_bIsLoading = true;
+	if (m_pCurOp)
+		delete m_pCurOp;
+	m_pCurOp = NULL;
+	if (m_DocPropDlg)
+		m_DocPropDlg->Destroy();
+	if (m_filename)
+		g_free (m_filename);
+	if (m_title)
+		g_free (m_title);
+	if (m_label)
+		g_free (m_label);
+	if (m_author)
+		g_free (m_author);
+	if (m_mail)
+		g_free (m_mail);
+	if (m_comment)
+		g_free (m_comment);
+	map<string, Object *>::iterator it;
+	Object *obj;
+	while (HasChildren ()) {
+		obj = GetFirstChild (it);
+		obj->Lock ();
+		Remove (obj);
+	}
+	m_pApp->RemoveDocument (this);
+	if (m_pView)
+		delete m_pView;
 }
 
 GtkWidget* gcpDocument::GetWidget()
@@ -227,6 +243,9 @@ bool gcpDocument::ImportOB(OBMol& Mol)
 		}
 	}
 	m_pApp->ActivateMenu ("Image", HasChildren ());
+	m_pView->Update (this);
+	Update ();
+	m_pView->EnsureSize ();
 	return true;
 }
 
@@ -370,7 +389,6 @@ void gcpDocument::AddFragment(gcpFragment* pFragment)
 	if (m_bIsLoading)
 		return;
 //	AddObject(pFragment);
-	pFragment->AnalContent();
 	if (!pFragment->GetMolecule())
 	{
 		int i0 = 1;
@@ -384,6 +402,7 @@ void gcpDocument::AddFragment(gcpFragment* pFragment)
 		AddChild(mol);
 		mol->AddFragment(pFragment);
 	}
+	pFragment->AnalContent();
 	m_bDirty = true;
 }
 
@@ -545,8 +564,10 @@ bool gcpDocument::Load (xmlNodePtr root)
 		node = node->next;
 	}
 	m_pView->Update (this);
+	Update ();
 	m_bIsLoading = false;
 	m_pApp->ActivateMenu ("Image", HasChildren ());
+	m_pView->EnsureSize ();
 	return true;
 }
 	
@@ -722,16 +743,19 @@ void gcpDocument::RemoveBond (gcpBond* pBond)
 	pAtom1 = (gcpAtom*) pBond->GetAtom (1);
 	gcpMolecule *pMol = (gcpMolecule*) pBond->GetMolecule ();
 	char id[16];
+	pMol->Lock (true);
 	pAtom0->RemoveBond (pBond);
 	m_pView->Update (pAtom0);
 	pAtom1->RemoveBond (pBond);
 	m_pView->Update (pAtom1);
+	pMol->Lock (false);
 	if (pBond->IsCyclic ()) {
 		pMol->Remove (pBond);
 		pMol->UpdateCycles ();
 		Update ();
 	} else {
 		Object *Parent = pMol->GetParent ();
+		Parent->Lock ();
 		int i0 = 1;
 		string align_id = pMol->GetAlignmentId ();
 		delete pMol;
@@ -778,6 +802,7 @@ void gcpDocument::RemoveBond (gcpBond* pBond)
 			m_pView->Update (pAtom0);
 		if ((pAtom1->GetZ () == 6) && (pAtom1->GetBondsNumber () == 0))
 			m_pView->Update (pAtom1);
+		Parent->Lock (false);
 	}
 	delete pBond;
 }
@@ -815,6 +840,8 @@ void gcpDocument::Remove(Object* pObject)
 				Object* object = pObject->GetFirstChild(i);
 				while (object)
 				{
+					if (pObject->IsLocked ())
+						object->Lock ();
 					Remove(object);
 					object = pObject->GetFirstChild(i);
 				}
@@ -890,6 +917,7 @@ void gcpDocument::OnUndo()
 		m_pApp->ActivateMenu("Undo", false);
 	m_pApp->ActivateMenu ("Image", HasChildren ());
 	m_bUndoRedo = false;
+	Update ();
 }
 
 void gcpDocument::OnRedo()
@@ -924,6 +952,7 @@ void gcpDocument::FinishOperation()
 	m_pCurOp = NULL;
 	m_bDirty = true;
 	m_pApp->ActivateMenu ("Image", HasChildren ());
+	Update ();
 }
 
 void gcpDocument::AbortOperation()
