@@ -4,7 +4,7 @@
  * GChemPaint library
  * document.h 
  *
- * Copyright (C) 2001-2004
+ * Copyright (C) 2001-2005
  *
  * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
  *
@@ -110,6 +110,7 @@ public:
 	void PushOperation(gcpOperation* operation, bool undo = true);
 	void SetActive();
 	gcpOperation* GetNewOperation(gcpOperationType type);
+	gcpOperation* GetCurrentOperation () {return m_pCurOp;}
 	void AddData(xmlNodePtr node);
 	bool CanUndo() {return m_UndoList.size() > 0;}
 	void SetBonoboUI(BonoboUIComponent *uic) {m_pUic = uic;}
@@ -119,6 +120,7 @@ public:
 	gcpApplication* GetApplication() {return m_pApp;}
 	bool IsDirty () {return m_bDirty;}
 	void ExportImage (const char* filename, const char* type);
+	void SetReadOnly (bool ro);
 
 private:
 	void RemoveAtom(gcpAtom* pAtom);
@@ -134,7 +136,7 @@ private:
 	gchar *m_comment, *m_author, *m_mail;
 	list<Object*>m_DirtyObjects;
 	BonoboPersist* m_ps;
-	bool m_bDirty, m_bIsLoading, m_bUndoRedo;
+	bool m_bDirty, m_bIsLoading, m_bUndoRedo, m_bReadOnly;
 	int m_FileType;
 	bool m_bWriteable;
 	gcpDocPropDlg* m_DocPropDlg;
