@@ -30,6 +30,7 @@
 #include "arrow.h"
 
 class gcpMesomery;
+class gcpMesomer;
 
 class gcpMesomeryArrow: public gcpArrow
 {
@@ -41,6 +42,14 @@ public:
 	virtual bool Load (xmlNodePtr);
 	virtual void Add (GtkWidget* w);
 	virtual void Update (GtkWidget* w);
+	void SetStartMesomer (gcpMesomer *Mesomer) {m_Start = Mesomer;}
+	gcpMesomer* GetStartMesomer () {return m_Start;}
+	void SetEndMesomer (gcpMesomer *Mesomer) {m_End = Mesomer;}
+	gcpMesomer* GetEndMesomer () {return m_End;}
+	void RemoveMesomer (gcpMesomer *Mesomer);
+
+private:
+	gcpMesomer *m_Start, *m_End;
 };
 
 #endif	//	GCHEMPAINT_MESOMERY_ARROW_H
