@@ -6,7 +6,7 @@
  *
  * Copyright (C) 2002-2004
  *
- * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -27,32 +27,22 @@
 #ifndef GCHEMPAINT_MESOMERY_H
 #define GCHEMPAINT_MESOMERY_H
 
-#include "arrow.h"
-
-class gcpMesomery;
-
-class gcpMesomeryArrow: public gcpArrow
-{
-public:
-	gcpMesomeryArrow(gcpMesomery* mesomery);
-	virtual ~gcpMesomeryArrow();
-	
-	virtual xmlNodePtr Save(xmlDocPtr xml);
-	virtual bool Load(xmlNodePtr);
-	virtual void Add(GtkWidget* w);
-	virtual void Update(GtkWidget* w);
-};
+#include <gcu/object.h>
 
+using namespace gcu;
 
 class gcpMesomery: public Object
 {
 public:
-	gcpMesomery();
-	virtual ~gcpMesomery();
+	gcpMesomery ();
+	virtual ~gcpMesomery ();
 	
-	virtual void Add(GtkWidget* w);
-	virtual xmlNodePtr Save(xmlDocPtr xml);
-	virtual bool Load(xmlNodePtr);
+	virtual void Add (GtkWidget* w);
+	virtual xmlNodePtr Save (xmlDocPtr xml);
+	virtual bool Load (xmlNodePtr);
 	virtual bool Build (list<Object*>& Children) throw (invalid_argument);
+	bool Validate (bool split);
+	void Align ();
 };
+
 #endif	//GCHEMPAINT_MESOMERY_H
