@@ -98,10 +98,13 @@ void gcpMolecule::AddBond(gcpBond* pBond)
 {
 	m_Bonds.push_back(pBond);
 	AddChild(pBond);
+	EmitSignal (OnChangedSignal);
 }
 
 void gcpMolecule::Remove(Object* pObject)
 {
+	if (pObject == m_Alignment)
+		m_Alignment = NULL;
 	switch (pObject->GetType())
 	{
 		case AtomType:
@@ -305,9 +308,12 @@ bool gcpMolecule::Merge(gcpMolecule* pMolecule, bool RemoveDuplicates)
 		m_Cycles.push_back(pCycle);
 		pMolecule->m_Cycles.pop_front();
 	}
+	Object* pObj = pMolecule->GetParent ();
 	delete pMolecule;
+	pObj->EmitSignal (OnChangedSignal);
 	if (RemoveDuplicates)
 		UpdateCycles ();
+	EmitSignal (OnChangedSignal);
 	return true;
 }
 
@@ -387,6 +393,7 @@ bool gcpMolecule::Load (xmlNodePtr node)
 
 void gcpMolecule::UpdateCycles()
 {
+	Lock (true);
 	std::list<gcpBond*>::iterator n;
 	for (n = m_Bonds.begin(); n != m_Bonds.end(); n++) (*n)->RemoveAllCycles();
 	while (!m_Cycles.empty())
@@ -402,6 +409,7 @@ void gcpMolecule::UpdateCycles()
 		gcpChain* pChain = new gcpChain(this, *(m_Atoms.begin())); //will find the cycles
 		delete pChain;
 	}
+	Lock (false);
 }
 
 void gcpMolecule::Clear()
