@@ -48,7 +48,7 @@ void gcpPlugin::LoadPlugins ()
 	const char* name;
 	while (name = g_dir_read_name (dir)) {
 		if (strcmp (name + strlen (name) - 3, ".so")) continue;
-		name = g_strconcat (LIBDIR"/gchempaint/plugins/", name);
+		name = g_strconcat (LIBDIR"/gchempaint/plugins/", name, NULL);
 		if (!dlopen (name, RTLD_NOW)) puts (dlerror());
 		g_free ((void*) name);
 	}
