@@ -4,7 +4,7 @@
  * GChemPaint library
  * reaction-step.h 
  *
- * Copyright (C) 2004
+ * Copyright (C) 2004-2005
  *
  * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
@@ -28,10 +28,12 @@
 #define GCHEMPAINT_REACTION_STEP_H
 
 #include <gcu/object.h>
+#include <set>
 
 using namespace gcu;
 
 class gcpReaction;
+class gcpReactionArrow;
 
 extern TypeId ReactionStepType;
 
@@ -48,8 +50,12 @@ public:
 	virtual double GetYAlign ();
 	virtual bool OnSignal (SignalId Signal, Object *Child);
 
+	void AddArrow (gcpReactionArrow *arrow) {m_Arrows.insert (arrow);}
+	void RemoveArrow (gcpReactionArrow *arrow);
+
 private:
 	bool m_bLoading;
+	set<gcpReactionArrow *> m_Arrows;
 };
 
 #endif	//	GCHEMPAINT_REACTION_STEP_H
