@@ -40,7 +40,7 @@ double DefaultStereoBondWidth = 20.0;
 double DefaultZoomFactor = 0.25;
 double DefaultPadding = 8.0;
 double DefaultArrowPadding = 64.0;
-double DefaultStoechiometryPadding = 4.;
+double DefaultStoichiometryPadding = 4.;
 double DefaultObjectPadding = 64.0;
 double DefaultSignPadding = 32.0;
 gchar* Color = "black";
