@@ -44,6 +44,8 @@ extern double DefaultArrowHeadB;
 extern double DefaultArrowHeadC;
 extern double DefaultArrowDist;
 extern double DefaultArrowPadding;
+extern double DefaultStoichiometryPadding;
+extern double DefaultObjectPadding;
 extern double DefaultSignPadding;
 extern gchar *Color, *DeleteColor, *AddColor, *SelectColor;
 extern gchar* DefaultFontFamily;
