@@ -284,9 +284,10 @@ bool gcpText::SaveNode(xmlDocPtr xml, xmlNodePtr node, GtkTextIter *iter, GtkTex
 	return true;
 }
 
-bool gcpText::Load(xmlNodePtr node)
+bool gcpText::Load (xmlNodePtr node)
 {
-	if (!gcpTextObject::Load(node)) return false;
+	if (!gcpTextObject::Load (node))
+		return false;
 	xmlNodePtr child;
 	m_bLoading = true;
 	child = node->children;
@@ -294,32 +295,38 @@ bool gcpText::Load(xmlNodePtr node)
 	gtk_text_buffer_get_iter_at_offset (m_buf, &iter, 0);
 	while (child)
 	{
-		LoadNode(child, &iter);
+		if (!LoadNode (child, &iter))
+			return false;
 		child = child->next;
 	}
 	m_bLoading = false;
-	OnChanged(m_buf);
+	OnChanged (m_buf);
+	return true;
 }
 
-bool gcpText::LoadSelection(xmlNodePtr node, GtkTextIter *iter)
+bool gcpText::LoadSelection (xmlNodePtr node, GtkTextIter *iter)
 {
 	xmlNodePtr child;
 	m_bLoading = true;
 	child = node->children;
 	while (child)
 	{
-		LoadNode(child, iter);
+		if (!LoadNode (child, iter))
+			return false;
 		child = child->next;
 	}
 	m_bLoading = false;
-	OnChanged(m_buf);
+	OnChanged (m_buf);
+	return true;
 }
 
-bool gcpText::LoadNode(xmlNodePtr node, GtkTextIter* CurIter)
+bool gcpText::LoadNode(xmlNodePtr node, GtkTextIter* CurIter, int level)
 {
 	char* tmp;
 	if (!strcmp((const char*)node->name, "text"))
 	{
+		if (!level)
+			return true;
 		tmp = (char*) xmlNodeGetContent(node);
 		if (tmp) {
 			gtk_text_buffer_insert(m_buf, CurIter, tmp, -1);
@@ -359,22 +366,23 @@ bool gcpText::LoadNode(xmlNodePtr node, GtkTextIter* CurIter)
 		xmlFree (TagName);
 		return result;
 	}
-	else return false;
+	else return true;
 }
 
-bool gcpText::LoadTaggedNode(xmlNodePtr node, GtkTextIter* CurIter, const char* TagName)
+bool gcpText::LoadTaggedNode (xmlNodePtr node, GtkTextIter* CurIter, const char* TagName)
 {
 	GtkTextIter start, end;
-	gint offset = gtk_text_iter_get_offset(CurIter);
+	gint offset = gtk_text_iter_get_offset (CurIter);
 	xmlNodePtr child = node->children;
-	while (child)
-	{
-		LoadNode(child, CurIter);
+	while (child) {
+		if (!LoadNode (child, CurIter, 1))
+			return false;
 		child = child->next;
 	}
-	gtk_text_buffer_get_iter_at_offset(m_buf, &start, offset);
-	gtk_text_buffer_get_selection_bounds(m_buf, NULL, &end);
-	gtk_text_buffer_apply_tag(m_buf, gtk_text_tag_table_lookup(TextTagTable, TagName), &start, &end);
+	gtk_text_buffer_get_iter_at_offset (m_buf, &start, offset);
+	gtk_text_buffer_get_selection_bounds (m_buf, NULL, &end);
+	gtk_text_buffer_apply_tag (m_buf, gtk_text_tag_table_lookup(TextTagTable, TagName), &start, &end);
+	return true;
 }
 
 void gcpText::Add(GtkWidget* w)
@@ -424,70 +432,78 @@ void gcpText::Add(GtkWidget* w)
 	if (g_object_get_data(G_OBJECT(item), "realized")) OnChanged(m_buf);
 }
 
-bool gcpText::OnChanged(GtkTextBuffer *textbuffer)
+bool gcpText::OnChanged (GtkTextBuffer *textbuffer)
 {
-	if (m_bLoading) return false;
-	if (textbuffer != m_buf) return false;
-	while (gtk_events_pending()) gtk_main_iteration();
-	gcpDocument* pDoc = (gcpDocument*)GetDocument();
-	if (!pDoc) return false;
-	gcpView* pView = pDoc->GetView();
-	GtkWidget* pWidget = pView->GetWidget();
-	gcpWidgetData* pData = (gcpWidgetData*)g_object_get_data(G_OBJECT(pWidget), "data");
-	if (!pData->Items[this])
-	{
-		pData->Items.erase(this);
+	if (m_bLoading)
+		return false;
+	if (textbuffer != m_buf)
+		return false;
+	while (gtk_events_pending ())
+		gtk_main_iteration();
+	gcpDocument* pDoc = (gcpDocument*) GetDocument ();
+	if (!pDoc)
+		return false;
+	gcpView* pView = pDoc->GetView ();
+	GtkWidget* pWidget = pView->GetWidget ();
+	gcpWidgetData* pData = (gcpWidgetData*) g_object_get_data (G_OBJECT (pWidget), "data");
+	if (!pData->Items[this]) {
+		pData->Items.erase (this);
 		return false;
 	}
-	GnomeCanvasRichTextExt* text = (GnomeCanvasRichTextExt*)g_object_get_data(G_OBJECT(pData->Items[this]), "text");
-	PangoLayout* layout = gnome_canvas_rich_text_ext_get_pango_layout(text, 0);
-	if (layout)
-	{
+	GnomeCanvasRichTextExt* text = (GnomeCanvasRichTextExt*) g_object_get_data (G_OBJECT (pData->Items[this]), "text");
+	PangoLayout* layout = gnome_canvas_rich_text_ext_get_pango_layout (text, 0);
+	if (layout) {
 		PangoLayoutIter* iter = pango_layout_get_iter(layout);
 		int base = pango_layout_iter_get_baseline(iter) / PANGO_SCALE;
-		if (base) m_ascent = base;
-		pango_layout_iter_free(iter);
+		if (base)
+			m_ascent = base;
+		pango_layout_iter_free (iter);
 	}
 	GdkRectangle rect;
 	GtkTextIter iter;
-	gtk_text_buffer_get_start_iter(m_buf,&iter);
-	int  y0 = 0, offset;
+	gtk_text_buffer_get_start_iter (m_buf,&iter);
+	int  y0 = 0, offset, left = 0;
 	m_height = 1;
 	bool bNotEnd = true;
 	m_length = 0;
 	if (!gtk_text_buffer_get_char_count (m_buf)) {
-		gnome_canvas_rich_text_ext_get_iter_location(text, &iter, &rect);
+		gnome_canvas_rich_text_ext_get_iter_location (text, &iter, &rect);
 		m_height = rect.height + 1;
 		m_length = 1;
 		pView->Update (this);
+		EmitSignal (OnChangedSignal);
 		return true;
 	}
-	while (bNotEnd)
-	{
-		bNotEnd = gtk_text_iter_forward_to_line_end(&iter);
-		gnome_canvas_rich_text_ext_get_iter_location(text, &iter, &rect);
-		if (m_length <= rect.x + rect.width) m_length = rect.x + rect.width + 1;
+	while (bNotEnd) {
+		gtk_text_iter_backward_line (&iter);
+		gnome_canvas_rich_text_ext_get_iter_location (text, &iter, &rect);
+		if (left > rect.x)
+			left = rect.x;
+		bNotEnd = gtk_text_iter_forward_to_line_end (&iter);
+		gnome_canvas_rich_text_ext_get_iter_location (text, &iter, &rect);
+		if (m_length <= rect.x + rect.width)
+			m_length = rect.x + rect.width + 1;
 		m_height += rect.height;
-		if (m_height <= rect.height + y0) m_height = rect.height + y0 + 1;
-		if (rect.y != y0)
-		{
-			while (rect.y != y0)
-			{
+		if (m_height <= rect.height + y0)
+			m_height = rect.height + y0 + 1;
+		if (rect.y != y0) {
+			while (rect.y != y0) {
 				int y = rect.y;
-				while (y == rect.y)
-				{
-					gtk_text_iter_backward_char(&iter);
-					gnome_canvas_rich_text_ext_get_iter_location(text, &iter, &rect);
+				while (y == rect.y) {
+					gtk_text_iter_backward_char (&iter);
+					gnome_canvas_rich_text_ext_get_iter_location (text, &iter, &rect);
 				}
 				m_length += rect.x + rect.width;
 			}
-			gtk_text_iter_forward_to_line_end(&iter);
+			gtk_text_iter_forward_to_line_end (&iter);
 		}
-		offset = gtk_text_iter_get_offset(&iter);
-		pView->Update(this);
-		while (gtk_events_pending()) gtk_main_iteration();
-		gtk_text_buffer_get_iter_at_offset(m_buf, &iter, offset + 1);
-		gnome_canvas_rich_text_ext_get_iter_location(text, &iter, &rect);
+		offset = gtk_text_iter_get_offset (&iter);
+		m_length -= left;
+		pView->Update (this);
+		while (gtk_events_pending ())
+			gtk_main_iteration ();
+		gtk_text_buffer_get_iter_at_offset (m_buf, &iter, offset + 1);
+		gnome_canvas_rich_text_ext_get_iter_location (text, &iter, &rect);
 		y0 = rect.y;
 	}
 	EmitSignal (OnChangedSignal);
@@ -670,3 +686,8 @@ void gcpText::Transform2D(Matrix2D& m, double x, double y)
 	m_x -= m_length / 2 - x;
 	m_y -= m_height / 2 - m_ascent - y;
 }
+	
+double gcpText::GetYAlign ()
+{
+	return m_y - ((gcpDocument*) GetDocument ())->GetView ()->GetBaseLineOffset ();
+}
