@@ -4,9 +4,9 @@
  * GChemPaint library
  * tool.cc
  *
- * Copyright (C) 2001-2004
+ * Copyright (C) 2001-2005
  *
- * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -48,24 +48,26 @@ gcpTool::~gcpTool()
 	m_pApp->SetTool (name, NULL);
 }
 
-bool gcpTool::OnClicked(gcpView* pView, Object* pObject, double x, double y, unsigned int state)
+bool gcpTool::OnClicked (gcpView* pView, Object* pObject, double x, double y, unsigned int state)
 {
 	m_x0 = m_x1 = lastx = x;
 	m_y0 = m_y1 = lasty = y;
 	m_nState = state;
 	m_bPressed = true;
 	m_pObject = pObject;
+	if (pObject)
+		m_pObjectGroup = pObject->GetGroup ();
 	m_pView = pView;
-	m_pWidget = m_pView->GetWidget();
-	m_pData = (gcpWidgetData*)g_object_get_data(G_OBJECT(m_pWidget), "data");
-	m_pGroup = gnome_canvas_root(GNOME_CANVAS(m_pWidget));
-	m_pBackground = m_pView->GetBackground();
-	m_dZoomFactor = m_pView->GetZoomFactor();
+	m_pWidget = m_pView->GetWidget ();
+	m_pData = (gcpWidgetData*) g_object_get_data (G_OBJECT(m_pWidget), "data");
+	m_pGroup = gnome_canvas_root (GNOME_CANVAS (m_pWidget));
+	m_pBackground = m_pView->GetBackground ();
+	m_dZoomFactor = m_pView->GetZoomFactor ();
 	Object* pAtom;
-	if (m_pObject && ((pAtom = m_pObject->GetAtomAt(m_x0 / m_dZoomFactor, m_y0 / m_dZoomFactor))))
+	if (m_pObject && ((pAtom = m_pObject->GetAtomAt (m_x0 / m_dZoomFactor, m_y0 / m_dZoomFactor))))
 			m_pObject = pAtom;
 	m_bAllowed = true;
-	return OnClicked();
+	return OnClicked ();
 }
 
 void gcpTool::OnDrag(double x, double y, unsigned int state)
