@@ -2,7 +2,7 @@
 
 /* 
  * GChemPaint library
- * widgetdata.h
+ * widgetdata.cc
  *
  * Copyright (C) 2002-2004
  *
@@ -187,6 +187,16 @@ void gcpWidgetData::MoveSelection(double dx, double dy)
 	pDoc->FinishOperation();
 }
 
+void gcpWidgetData::RotateSelection(double dx, double dy, double angle)
+{
+	std::list<Object*>::iterator i;
+	Matrix2D m(angle);
+	for (i = SelectedObjects.begin(); i != SelectedObjects.end(); i++) {
+		(*i)->Transform2D (m, dx / ZoomFactor, dy / ZoomFactor);
+		View->Update(*i);
+	}
+}
+
 void gcpWidgetData::Copy(GtkClipboard* clipboard)
 {
 	/*First build the XML tree from current selection*/
@@ -238,7 +248,6 @@ void gcpWidgetData::GetObjectBounds(Object* obj, ArtDRect &rect)
 		GetObjectBounds(pObject, rect);
 		pObject = obj->GetNextChild(i);
 	}
-	
 }
 
 void gcpWidgetData::GetSelectionBounds(ArtDRect &rect)
@@ -249,15 +258,23 @@ void gcpWidgetData::GetSelectionBounds(ArtDRect &rect)
 		GetObjectBounds(*i, rect);
 }
 
+void gcpWidgetData::GetObjectBounds(Object* obj, ArtDRect *rect)
+{
+	rect->x0 = -1.;
+	GetObjectBounds(obj, *rect);
+}
+
 void gcpWidgetData::SelectAll()
 {
 	std::map<Object*, GnomeCanvasGroup*>::iterator i;
 	Object *pObject;
 	for (i = Items.begin(); i != Items.end(); i++)
 	{
-		pObject = (*i).first->GetMolecule();
-		if (pObject)
-			SetSelected(pObject);
+		pObject = (*i).first->GetGroup();
+		if (pObject) {
+			if (!IsSelected(pObject))
+				SetSelected(pObject);
+		}
 		else
 			SetSelected((*i).first);
 	}
