@@ -508,7 +508,7 @@ void gcpArrowTool::OnRelease()
 		}
 		break;
 	case gcpDoubleQueuedArrow: {
-			a = new gcpRetrosynthesisArrow ();
+			a = new gcpRetrosynthesisArrow (NULL);
 			a->SetCoords(m_x0 / m_dZoomFactor, m_y0 / m_dZoomFactor, m_x1 / m_dZoomFactor, m_y1 / m_dZoomFactor);
 			pDoc->AddObject(a);
 		}
