@@ -33,6 +33,8 @@ using namespace gcu;
 
 extern TypeId RetrosynthesisType;
 
+class gcpRetrosynthesisStep;
+
 class gcpRetrosynthesis: public Object
 {
 public:
@@ -43,6 +45,17 @@ public:
 	virtual xmlNodePtr Save (xmlDocPtr xml);
 	virtual bool Load (xmlNodePtr);
 	virtual bool Build (list<Object*>& Children) throw (invalid_argument);
+	virtual double GetYAlign ();
+	virtual bool BuildContextualMenu (GtkUIManager *UIManager, Object *object);
+	virtual bool OnSignal (SignalId Signal, Object *Child);
+	int Validate (bool split);
+	void Align ();
+
+private:
+	gcpRetrosynthesis (Object* parent, gcpRetrosynthesisStep *step);
+
+private:
+	gcpRetrosynthesisStep *Target;
 };
 
 #endif	// GCHEMPAINT_RETROSYNTHESIS_H
