@@ -26,6 +26,7 @@
 
 #include "retrosynthesisarrow.h"
 #include "retrosynthesis.h"
+#include "retrosynthesisstep.h"
 #include "lib/settings.h"
 #include "lib/view.h"
 #include "lib/widgetdata.h"
@@ -35,12 +36,22 @@
 
 TypeId RetrosynthesisArrowType = NoType;
 
-gcpRetrosynthesisArrow::gcpRetrosynthesisArrow(): gcpArrow (RetrosynthesisArrowType)
+gcpRetrosynthesisArrow::gcpRetrosynthesisArrow(gcpRetrosynthesis *rs): gcpArrow (RetrosynthesisArrowType)
 {
+	SetId ("rsa1");
+	if (rs)
+		rs->AddChild( this);
+	m_Start = m_End = NULL;
 }
 
 gcpRetrosynthesisArrow::~gcpRetrosynthesisArrow()
 {
+	if (IsLocked ())
+		return;
+	if (m_Start && m_End) {
+		m_Start->RemoveArrow (this, m_End);
+		m_End->RemoveArrow (this, m_Start);
+	}
 }
 
 xmlNodePtr gcpRetrosynthesisArrow::Save (xmlDocPtr xml)
@@ -53,6 +64,10 @@ xmlNodePtr gcpRetrosynthesisArrow::Save (xmlDocPtr xml)
 		xmlFreeNode (node);
 		return NULL;
 	}
+	if (m_Start)
+		xmlNewProp (node, (xmlChar*) "start",  (xmlChar*) m_Start->GetId ());
+	if (m_End)
+		xmlNewProp (node, (xmlChar*) "end",  (xmlChar*) m_End->GetId ());
 	gcpRetrosynthesis* r = (gcpRetrosynthesis*) GetParentOfType (RetrosynthesisType);
 	if (!r)
 	{
@@ -70,7 +85,32 @@ xmlNodePtr gcpRetrosynthesisArrow::Save (xmlDocPtr xml)
 
 bool gcpRetrosynthesisArrow::Load(xmlNodePtr node)
 {
-	return gcpArrow::Load(node);
+	char *buf;
+	Object *parent;
+	if (gcpArrow::Load (node)) {
+		parent = GetParent ();
+		if (!parent)
+			return true;
+		buf = (char*) xmlGetProp (node, (xmlChar*) "start");
+		if (buf) {
+			m_Start = reinterpret_cast<gcpRetrosynthesisStep*> (parent->GetDescendant (buf));
+			xmlFree (buf);
+			if (!m_Start)
+				return false;
+		}
+		buf = (char*) xmlGetProp (node, (xmlChar*) "end");
+		if (buf) {
+			m_End = reinterpret_cast<gcpRetrosynthesisStep*> (parent->GetDescendant (buf));
+			xmlFree (buf);
+			if (!m_End)
+				return false;
+			m_End->AddArrow (this, m_Start, false);
+		}
+		if (m_Start)
+			m_Start->AddArrow (this, m_End, true);
+		return true;
+	}
+	return false;
 }
 
 void gcpRetrosynthesisArrow::Add (GtkWidget* w)
