@@ -4,9 +4,9 @@
  * GChemPaint bonds plugin
  * bondtool.cc
  *
- * Copyright (C) 2001-2004
+ * Copyright (C) 2001-2005
  *
- * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -35,18 +35,18 @@
 #include "lib/bond.h"
 #include "libgcpcanvas/gcp-canvas-group.h"
 
-gcpBondTool::gcpBondTool(gcpApplication *App, string ToolId, unsigned nPoints): gcpTool(App, ToolId)
+gcpBondTool::gcpBondTool (gcpApplication *App, string ToolId, unsigned nPoints): gcpTool (App, ToolId)
 {
 	points = (nPoints)? gnome_canvas_points_new (nPoints): NULL;
 	m_pOp = NULL;
 }
 
-gcpBondTool::~gcpBondTool()
+gcpBondTool::~gcpBondTool ()
 {
-	if (points) gnome_canvas_points_free(points);
+	if (points) gnome_canvas_points_free (points);
 }
 
-bool gcpBondTool::OnClicked()
+bool gcpBondTool::OnClicked ()
 {
 	double x1, y1, x2, y2;
 	int i;
@@ -55,18 +55,18 @@ bool gcpBondTool::OnClicked()
 	m_bChanged = false;
 	m_dAngle = 0.;
 	gcpBond* pBond;
-	gcpDocument* pDoc = m_pView->GetDoc();
+	gcpDocument* pDoc = m_pView->GetDoc ();
 	if (m_pObject)
 	{
-		TypeId Id = m_pObject->GetType();
+		TypeId Id = m_pObject->GetType ();
 		switch (Id)
 		{
 		case BondType:
-			pBond = (gcpBond*)m_pObject;
-			m_pAtom = (gcpAtom*)pBond->GetAtom(0);
-			m_pAtom->GetCoords(&m_x0, &m_y0, NULL);
-			m_pAtom = (gcpAtom*)pBond->GetAtom(1);
-			m_pAtom->GetCoords(&m_x1, &m_y1, NULL);
+			pBond = (gcpBond*) m_pObject;
+			m_pAtom = (gcpAtom*) pBond->GetAtom (0);
+			m_pAtom->GetCoords (&m_x0, &m_y0, NULL);
+			m_pAtom = (gcpAtom*) pBond->GetAtom (1);
+			m_pAtom->GetCoords (&m_x1, &m_y1, NULL);
 			m_x0 *= m_dZoomFactor;
 			m_y0 *= m_dZoomFactor;
 			m_x1 *= m_dZoomFactor;
@@ -74,9 +74,9 @@ bool gcpBondTool::OnClicked()
 			points->coords[0] = m_x0;
 			points->coords[1] = m_y0;
 			m_bChanged = true;
-			m_pOp = pDoc-> GetNewOperation(GCP_MODIFY_OPERATION);
-			m_pOp->AddObject(m_pObject, 0);
-			UpdateBond();
+			m_pOp = pDoc->GetNewOperation (GCP_MODIFY_OPERATION);
+			m_pOp->AddObject (m_pObjectGroup, 0);
+			UpdateBond ();
 			return true;
 		case AtomType:
 			if (!((gcpAtom*)m_pObject)->AcceptNewBonds()) return false;
@@ -278,23 +278,21 @@ void gcpBondTool::OnRelease()
 		m_pOp = NULL;
 		return;
 	}
-	if ((m_pObject) && (m_pObject->GetType() == BondType))
-	{
-		FinalizeBond();
-		gcpAtom* pAtom = (gcpAtom*) ((gcpBond*)m_pObject)->GetAtom(0);
+	if ((m_pObject) && (m_pObject->GetType() == BondType)) {
+		FinalizeBond ();
+		gcpAtom* pAtom = (gcpAtom*) ((gcpBond*) m_pObject)->GetAtom (0);
 		pAtom->Update ();
-		m_pView->Update(pAtom);
-		pAtom = (gcpAtom*) ((gcpBond*)m_pObject)->GetAtom(1);
+		m_pView->Update (pAtom);
+		pAtom = (gcpAtom*) ((gcpBond*) m_pObject)->GetAtom (1);
 		pAtom->Update ();
-		m_pView->Update(pAtom);
-		m_pOp->AddObject(m_pObject, 1);
-		pDoc->FinishOperation();
+		m_pView->Update (pAtom);
+		m_pOp->AddObject (m_pObjectGroup, 1);
+		pDoc->FinishOperation ();
 		m_pOp = NULL;
 		return;
-	}
-	else 
-	{
-		if (m_pOp) pDoc->AbortOperation();
+	} else {
+		if (m_pOp)
+			pDoc->AbortOperation();
 		m_pOp = NULL;
 	}
 	m_pApp->ClearStatus();
@@ -320,19 +318,27 @@ void gcpBondTool::OnRelease()
 	}
 	gcpAtom* pAtom;
 	gcpBond* pBond;
-	if (!m_pObject)
-	{
+	if (!m_pObject) {
 		//Add an atom at (x0, y0)
-		pAtom = new gcpAtom(m_pApp->GetCurZ(), m_x0 / m_dZoomFactor, m_y0 / m_dZoomFactor, 0);
-		pDoc->AddAtom(pAtom);
+		pAtom = new gcpAtom (m_pApp->GetCurZ(), m_x0 / m_dZoomFactor, m_y0 / m_dZoomFactor, 0);
+		pDoc->AddAtom (pAtom);
 		m_pObject = pAtom;
+	} else {
+		pObject = m_pObject->GetGroup ();
+		if (pObject)
+			ModifiedObjects.insert (pObject->GetId ());
 	}
 	if (m_pObject->GetType() == AtomType)
 	{
 		if (m_pAtom) {
 			if (m_pObject == m_pAtom) {
+				ModifiedObjects.clear ();
 				return;
 			}
+			pObject = m_pObject->GetGroup ();
+			if (!pObject)
+				throw runtime_error (_("Invalid document tree, please file a bug report"));
+			ModifiedObjects.insert (pObject->GetId ());
 			pAtom = m_pAtom;
 		} else {
 			pAtom = new gcpAtom(m_pApp->GetCurZ(), m_x1 / m_dZoomFactor, m_y1 / m_dZoomFactor, 0);
@@ -342,7 +348,7 @@ void gcpBondTool::OnRelease()
 		if (pBond)
 		{
 			m_pOp = pDoc-> GetNewOperation(GCP_MODIFY_OPERATION);
-			m_pOp->AddObject(pBond, 0);
+			m_pOp->AddObject(pBond->GetGroup (), 0);
 			if (pBond->GetType() == NormalBondType)	pBond->IncOrder();
 			m_pObject = pBond;
 			m_bChanged = true;
@@ -354,17 +360,37 @@ void gcpBondTool::OnRelease()
 			pAtom->Update ();
 			m_pView->Update(pAtom);
 			m_pView->Update(pBond);
-			m_pOp->AddObject(pBond, 1);
+			m_pOp->AddObject(pBond->GetGroup (), 1);
 			pDoc->FinishOperation();
 			m_pOp = NULL;
 		}
 		else
 		{
+			// Push modified objects in Operation
+			if (ModifiedObjects.size ()) {
+				m_pOp = pDoc-> GetNewOperation(GCP_MODIFY_OPERATION);
+				set<string>::iterator it, end = ModifiedObjects.end();
+				for (it = ModifiedObjects.begin(); it != end; it++)
+					m_pOp->AddObject (pDoc->GetDescendant ((*it).c_str ()), 0);
+			}
 			pBond = new gcpBond((gcpAtom*)m_pObject, pAtom, 1);
 			SetType(pBond);
 			pDoc->AddBond(pBond);
+			if (m_pOp) {
+				set<string>::iterator it, end = ModifiedObjects.end();
+				for (it = ModifiedObjects.begin(); it != end; it++) {
+					pObject = pDoc->GetDescendant ((*it).c_str ());
+					if (pObject)
+						m_pOp->AddObject (pObject, 1);
+				}
+			} else {
+				m_pOp = pDoc-> GetNewOperation(GCP_ADD_OPERATION);
+				m_pOp->AddObject (pBond->GetMolecule ());
+			}
+			pDoc->FinishOperation();
 		}
 	}
+	ModifiedObjects.clear ();
 }
 
 void gcpBondTool::Draw()
@@ -608,7 +634,6 @@ gcpSquiggleBondTool::~gcpSquiggleBondTool()
 
 void gcpSquiggleBondTool::Draw()
 {
-	while(gtk_events_pending()) gtk_main_iteration();
 	GnomeCanvasPathDef *path_def;
 	path_def = gnome_canvas_path_def_new();
 	gnome_canvas_path_def_moveto(path_def, m_x0, m_y0);
