@@ -623,9 +623,7 @@ void gcpCycleTool::OnRelease()
 	pDoc->FinishOperation ();
 	if (pMol) {
 		pMol->Lock (false);
-puts("updating group");
 		pMol->EmitSignal (OnChangedSignal);
-puts("done updating group");
 	}
 	ModifiedObjects.clear ();
 }
