@@ -4,9 +4,9 @@
  * GChemPaint selection plugin
  * erasertool.cc
  *
- * Copyright (C) 2001-2004
+ * Copyright (C) 2001-2005
  *
- * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -28,7 +28,6 @@
 #include <math.h>
 #include "erasertool.h"
 #include "lib/settings.h"
-//#include "lib/mendeleiev.h"
 #include "lib/document.h"
 #include "lib/atom.h"
 #include "lib/bond.h"
@@ -46,9 +45,11 @@ bool gcpEraserTool::OnClicked()
 {
 	if (m_pObject)
 	{
+		TypeId Id = m_pObject->GetType();
+		if (Id == ReactionOperatorType)
+			return false; //It's an automatic object, don't delete it
 		m_pObject->SetSelected(m_pWidget, SelStateErasing);
 		m_pItem = m_pView->GetCanvasItem(m_pWidget, m_pObject);
-		TypeId Id = m_pObject->GetType();
 		if (Id == AtomType)
 		{
 			Object* parent = m_pObject->GetParent();
@@ -150,23 +151,45 @@ void gcpEraserTool::OnDrag()
 
 void gcpEraserTool::OnRelease()
 {
+	char *id = NULL;
 	if ((!m_pObject) || (!m_bChanged))
 	{
 		m_pItem = NULL;
 		return;
 	}
 	gcpDocument* pDoc = m_pView->GetDoc();
+	gcpOperation *pOp;
+	Object *pObj = m_pObject->GetGroup (), *Parent;
+	if (pObj && pObj->GetType () != MoleculeType) {
+		pOp = pDoc->GetNewOperation (GCP_MODIFY_OPERATION);
+		pOp->AddObject (pObj, 0);
+		id = g_strdup (pObj->GetId ());
+	} else {
+		pOp = pDoc->GetNewOperation (GCP_DELETE_OPERATION);
+		pOp->AddObject (m_pObject);
+	}
 	if (m_pObject->GetType() == AtomType)
 	{
 		Object* parent = m_pObject->GetParent();
 		if (parent->GetType() == FragmentType)	m_pObject = parent;
 	}
-	m_pObject->EmitSignal (OnDeleteSignal);
+//	m_pObject->EmitSignal (OnDeleteSignal); /* This might be not useful */
+	Parent = m_pObject->GetParent ();
+// A molecule might disappear, so get its parent
+	if (Parent->GetType () == MoleculeType)
+		Parent = Parent->GetParent ();
 	m_pItem = NULL;
 	if (m_pData->Items[m_pObject] == NULL) {
 		m_pData->Items.erase(m_pObject);
 		return;
 	}
 	pDoc->Remove(m_pObject);
+	Parent->EmitSignal (OnChangedSignal);
+	if (id) {
+		pObj = pDoc->GetChild (id);
+		if (pObj)
+			pOp->AddObject (pObj, 1);
+		g_free (id);
+	}
 	pDoc->FinishOperation();
 }
