@@ -1,16 +1,14 @@
-#include <libgnome/libgnome.h>
-#include <libgnomeui/libgnomeui.h>
+#include "gchempaint-config.h"
 #include <libbonobo.h>
 #include <libbonoboui.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
-#include "config.h"
 
 CORBA_Environment	 ev;
 
 static guint
 create_app (void)
 {
-	GtkWidget *control;
+	GtkWidget *box, *control, *label, *button;
 	BonoboWindow *bonobo_win;
 
 	BonoboUIContainer *uic;
@@ -59,12 +57,12 @@ create_app (void)
 	  int 
 main (int argc, char** argv)
 {
+	CORBA_ORB orb;
+
 	GnomeProgram* prog;
 	
 	CORBA_exception_init (&ev);
-	prog = gnome_program_init ("bonobo-control-test", "0.0", LIBGNOMEUI_MODULE, argc, argv, 
-                   GNOME_PARAM_POPT_TABLE, NULL, 
-                   GNOME_PROGRAM_STANDARD_PROPERTIES, NULL);
+	gtk_init (&argc, &argv);
 
 	/*
 	 * initialize CORBA, OAF  and bonobo
